{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% trans "Account inactive" %}{% endblock %}
{% block page_title %}{% trans "Account inactive" %}{% endblock %}

{% block content %}
  <div class="container">
    <div class="card red">
      <div class="card-content white-text">
        <div class="card-title">
          <i class="material-icons iconify small left" data-icon="mdi:alert-octagon-outline"></i>
          {% blocktrans %}Account inactive.{% endblocktrans %}
        </div>
        <p>
          {% blocktrans %}
            This account is currently inactive. If you think this is an
            error, please contact one of your site administrators.
          {% endblocktrans %}
        </p>
        {% include "core/partials/admins_list.html" %}
      </div>
    </div>
  </div>
{% endblock %}
